***********
Basic Usage
***********

Installation
============
Install ``stepwise_mol_bio`` using ``pip``::

    $ pip install stepwise_mol_bio

- Requires python≥3.8
- Uses `semantic versioning`_.

.. _`semantic versioning`: https://semver.org/
